@@ -14,6 +14,7 @@ import StringIO
 
 log = Util.get_log('ETL')
 
+
 class ETL:
     """The main class: builds ETL Chains with connected Components from a config and let them run.
 
@@ -70,10 +71,9 @@ class ETL:
             else:
                 # Parse config file directly
                 self.configdict.read(config_file)
-        except Exception, e:
+        except Exception as e:
             log.error("Fatal Error reading config file: err=%s" % str(e))
 
-
     def run(self):
         # The main ETL processing
         log.info("START")
@@ -94,7 +94,7 @@ class ETL:
         chains_str_arr = chains_str.split(',')
         for chain_str in chains_str_arr:
             # Build single Chain of components and let it run
-            chain = Chain(chain_str.strip(), self.configdict)
+            chain = Chain(chain_str, self.configdict)
             chain.assemble()
 
             # Run the ETL for this Chain
