@@ -10,6 +10,8 @@ from stetl.util import Util, etree
 from stetl.utils.apachelog import formats, parser
 from stetl.packet import FORMAT
 import csv
+import re
+import fnmatch
 
 log = Util.get_log('fileinput')
 
@@ -22,29 +24,20 @@ class FileInput(Input):
     # Start attribute config meta
     # Applying Decorator pattern with the Config class to provide
     # read-only config values from the configured properties.
-    
+
     @Config(ptype=str, default=None, required=False)
     def file_path(self):
         """
         Path to file or files or URLs: can be a dir or files or URLs
         or even multiple, comma separated. For URLs only JSON is supported now.
-
-        Required: True
-
-        Default: None
         """
         pass
 
-
     @Config(ptype=str, default='*.[gxGX][mM][lL]', required=False)
     def filename_pattern(self):
         """
         Filename pattern according to Python ``glob.glob`` for example:
-        '\*.[gxGX][mM][lL]'
-
-        Required: False
-
-        Default: '\*.[gxGX][mM][lL]'
+        '\\*.[gxGX][mM][lL]'
         """
         pass
 
@@ -52,10 +45,6 @@ class FileInput(Input):
     def depth_search(self):
         """
         Should we recurse into sub-directories to find files?
-
-        Required: False
-
-        Default: False
         """
         pass
 
@@ -70,6 +59,7 @@ class FileInput(Input):
         if not len(self.file_list):
             raise Exception('File list is empty!!')
 
+        self.cur_file_path = None
         self.file_list_done = []
 
     def read(self, packet):
@@ -112,10 +102,6 @@ class StringFileInput(FileInput):
         Formatting of content according to Python String.format()
         Input file should have substitutable values like {schema} {foo}
         format_args should be of the form ``format_args = schema:test foo:bar``
-
-        Required: False
-
-        Default: None
         """
         pass
 
@@ -128,40 +114,24 @@ class StringFileInput(FileInput):
         # Optional formatting of content according to Python String.format()
         # Input file should have substitutable values like {schema} {foo}
         # format_args should be of the form format_args = schema:test foo:bar
-
         if self.format_args:
             # Convert string to dict: http://stackoverflow.com/a/1248990
             self.format_args = Util.string_to_dict(self.format_args, ':')
 
-    def read(self, packet):
-        # No more files left and done with current file ?
-        if not len(self.file_list) and self.file is None:
-            packet.set_end_of_stream()
-            log.info("EOF file list, all files done")
-            return packet
+    def read_file(self, file_path):
+        """
+        Overridden from base class.
+        """
 
-        # Done with current file or first file ?
-        if self.file is None:
-            self.cur_file_path = self.file_list.pop(0)
-            self.file = open(self.cur_file_path, 'r')
-            log.info("file opened : %s" % self.cur_file_path)
+        file_content = None
+        with open(file_path, 'r') as f:
+            file_content = f.read()
+            # Optional: string substitution based on Python String.format()
+            # But you can also use StringSubstitutionFilter from filters.
+            if self.format_args:
+                file_content = file_content.format(**self.format_args)
 
-        # Assume valid file content
-        file_content = self.file.read()
-
-        # Optional: string substitution based on Python String.format()
-        # But you can also use StringSubstitutionFilter from filters.
-        if self.format_args:
-            file_content = file_content.format(**self.format_args)
-
-        # Cleanup
-        self.file.close()
-        self.file = None
-
-        log.info("file read : %s size=%d" % (self.cur_file_path, len(file_content)))
-
-        packet.data = file_content
-        return packet
+        return file_content
 
 
 class XmlFileInput(FileInput):
@@ -180,13 +150,12 @@ class XmlFileInput(FileInput):
         data = None
         try:
             data = etree.parse(file_path)
-        except Exception, e:
-            log.info("file read and parsed NOT OK : %s" % file_path)
+        except Exception as e:
+            log.info('file read and parsed NOT OK : %s, err=%s' % (file_path, str(e)))
 
         return data
 
 
-
 class XmlElementStreamerFileInput(FileInput):
     """
     Extracts XML elements from a file, outputs each feature element in Packet.
@@ -202,10 +171,6 @@ class XmlElementStreamerFileInput(FileInput):
         """
         Comma-separated string of XML (feature) element tag names of the elements that should be extracted
         and added to the output element stream.
-
-        Required: True
-
-        Default: None
         """
         pass
 
@@ -213,10 +178,6 @@ class XmlElementStreamerFileInput(FileInput):
     def strip_namespaces(self):
         """
         should namespaces be removed from the input document and thus not be present in the output element stream?
-
-        Required: False
-
-        Default: False
         """
         pass
 
@@ -228,7 +189,6 @@ class XmlElementStreamerFileInput(FileInput):
         self.file_list_done = []
         self.context = None
         self.root = None
-        self.cur_file_path = None
         self.elem_count = 0
         log.info("Element tags to be matched: %s" % self.element_tags)
 
@@ -298,18 +258,15 @@ class XmlElementStreamerFileInput(FileInput):
 
         return packet
 
-class XmlLineStreamerFileInput(FileInput):
+
+class LineStreamerFileInput(FileInput):
     """
-    DEPRECATED Streams lines from an XML file(s)
+    Reads text-files, producing a stream of lines, one line per Packet.
     NB assumed is that lines in the file have newlines !!
-    DEPRECATED better is to use XmlElementStreamerFileInput for GML features.
-
-    produces=FORMAT.xml_line_stream
     """
 
-    # Constructor
-    def __init__(self, configdict, section):
-        FileInput.__init__(self, configdict, section, produces=FORMAT.xml_line_stream)
+    def __init__(self, configdict, section, produces=FORMAT.line_stream):
+        FileInput.__init__(self, configdict, section, produces)
         self.file_list_done = []
         self.file = None
 
@@ -350,9 +307,31 @@ class XmlLineStreamerFileInput(FileInput):
 
             return packet
 
-        packet.data = line.decode('utf-8')
+        line = line.decode('utf-8')
+        packet.data = self.process_line(line)
+
         return packet
 
+    def process_line(self, line):
+        """
+        Override in subclass.
+        """
+        return line
+
+
+class XmlLineStreamerFileInput(LineStreamerFileInput):
+    """
+    DEPRECATED Streams lines from an XML file(s)
+    NB assumed is that lines in the file have newlines !!
+    DEPRECATED better is to use XmlElementStreamerFileInput for GML features.
+
+    produces=FORMAT.xml_line_stream
+    """
+
+    # Constructor
+    def __init__(self, configdict, section):
+        LineStreamerFileInput.__init__(self, configdict, section, produces=FORMAT.xml_line_stream)
+
 
 class CsvFileInput(FileInput):
     """
@@ -366,22 +345,14 @@ class CsvFileInput(FileInput):
     def delimiter(self):
         """
         A one-character string used to separate fields. It defaults to ','.
-
-        Required: False
-
-        Default: ',' (comma)
         """
         pass
 
-
     @Config(ptype=str, default='"', required=False)
     def quote_char(self):
         """
-        A one-character string used to quote fields containing special characters, such as the delimiter or quotechar, or which contain new-line characters. It defaults to '"'
-
-        Required: False
-
-        Default: "
+        A one-character string used to quote fields containing special characters, such as the delimiter or quotechar,
+        or which contain new-line characters. It defaults to '"'.
         """
         pass
 
@@ -409,7 +380,7 @@ class CsvFileInput(FileInput):
                     packet.data = self.csv_reader.next()
 
             log.info("CSV row nr %d read: %s" % (self.csv_reader.line_num - 1, packet.data))
-        except Exception, e:
+        except Exception:
             if self._output_format == FORMAT.record_array:
                 packet.data = self.arr
 
@@ -447,12 +418,13 @@ class JsonFileInput(FileInput):
                 with open(file_path) as data_file:
                     file_data = json.load(data_file)
 
-        except Exception, e:
+        except Exception as e:
             log.error('Cannot read JSON from %s, err= %s' % (file_path, str(e)))
             raise e
 
         return file_data
 
+
 class ApacheLogFileInput(FileInput):
     """
     Parses Apache log files. Lines are converted into records based on the log format.
@@ -462,19 +434,13 @@ class ApacheLogFileInput(FileInput):
 
     """
 
-    @Config(ptype=dict, default=
-    {'%l': 'logname', '%>s': 'status', '%D': 'deltat', '%{User-agent}i': 'agent', '%b': 'bytes', '%{Referer}i': 'referer', '%u': 'user', '%t': 'time', "'%h": 'host', '%r': 'request'}
-    , required=False)
+    @Config(ptype=dict, default={'%l': 'logname', '%>s': 'status', '%D': 'deltat',
+                                 '%{User-agent}i': 'agent', '%b': 'bytes', '%{Referer}i': 'referer',
+                                 '%u': 'user', '%t': 'time', "'%h": 'host', '%r': 'request'}, required=False)
     def key_map(self):
         """
         Map of cryptic %-field names to readable keys in record.
 
-        Type: dictionary
-
-        Required: False
-
-        Default:  {'%l': 'logname', '%>s': 'status', '%D': 'deltat', '%{User-agent}i': 'agent', '%b': 'bytes', '%{Referer}i': 'referer', '%u': 'user', '%t': 'time', "'%h": 'host', '%r': 'request'}
-
         """
         pass
 
@@ -482,10 +448,6 @@ class ApacheLogFileInput(FileInput):
     def log_format(self):
         """
         Log format according to Apache CLF
-
-        Required: False
-
-        Default: '%h %l %u %t \"%r\" %>s %b \"%{Referer}i\" \"%{User-agent}i\"'
         """
         pass
 
@@ -494,7 +456,7 @@ class ApacheLogFileInput(FileInput):
         FileInput.__init__(self, configdict, section, produces=FORMAT.record)
         self.file_list_done = []
         self.file = None
-        self.parser = parser(self.log_format, self.key_map, options={'methods': ['GET','POST'],
+        self.parser = parser(self.log_format, self.key_map, options={'methods': ['GET', 'POST'],
                                                                      'use_native_types': True,
                                                                      'request_path_only': True,
                                                                      'gen_key': True})
@@ -541,3 +503,83 @@ class ApacheLogFileInput(FileInput):
         return packet
 
 
+class ZipFileInput(FileInput):
+    """
+    Parse ZIP file from file system or URL into a stream of records containing zipfile-path and file names.
+
+    produces=FORMAT.record
+    """
+
+    @Config(ptype=str, default='*', required=False)
+    def name_filter(self):
+        """
+        Regular "glob.glob" expression for filtering out filenames from the ZIP archive.
+        """
+        pass
+
+    def __init__(self, configdict, section):
+        FileInput.__init__(self, configdict, section, produces=FORMAT.record)
+        self.file_content = None
+
+        # Pre-compile name filter into regex object to match filenames in zip-archive(s) later
+        # See default (*) above, so we alo have a name_filter.
+        self.fname_matcher = re.compile(fnmatch.translate(self.name_filter))
+
+    def read(self, packet):
+        # No more files left and done with current file ?
+        if not self.file_content and not len(self.file_list):
+            packet.set_end_of_stream()
+            log.info("EOF file list, all files done")
+            return packet
+
+        # Done with current file or first file ?
+        if self.file_content is None:
+            self.cur_file_path = self.file_list.pop(0)
+
+            # Assemble list of file names in archive
+            import zipfile
+            zf = zipfile.ZipFile(self.cur_file_path, 'r')
+            namelist = [{'file_path': self.cur_file_path, 'name': name} for name in zf.namelist()]
+
+            # Apply filename filter to namelist (TODO could be done in single step with previous step)
+            self.file_content = [item for item in namelist if self.fname_matcher.match(item["name"])]
+
+            log.info("zip file read : %s filecount=%d" % (self.cur_file_path, len(self.file_content)))
+
+        if len(self.file_content):
+            packet.data = self.file_content.pop(0)
+            log.info("Pop file record: %s" % str(packet.data))
+
+        if not len(self.file_content):
+            self.file_content = None
+
+        return packet
+
+
+class GlobFileInput(FileInput):
+    """
+    Returns file names based on the glob.glob pattern given as filename_filter.
+
+    produces=FORMAT.string or FORMAT.line_stream
+    """
+
+    def __init__(self, configdict, section, produces=[FORMAT.string, FORMAT.line_stream]):
+        FileInput.__init__(self, configdict, section, produces)
+
+    def read(self, packet):
+        if not len(self.file_list):
+            return packet
+
+        file_path = self.file_list.pop(0)
+
+        # TODO: os.path.join?
+        packet.data = file_path
+
+        # One-time read: we're all done
+        packet.set_end_of_doc()
+        if not len(self.file_list):
+            log.info("all files done")
+            packet.set_end_of_stream()
+
+        self.file_list_done.append(file_path)
+        return packet
