@@ -4,13 +4,17 @@
 #
 # Author:Just van den Broecke
 
-import logging, os, glob, sys, types
-from time import *
+import logging
+import os
+import glob
+import types
+from time import time
 from ConfigParser import ConfigParser
 
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(name)s %(levelname)s %(message)s')
 
+
 # Static utility methods
 class Util:
     # http://wiki.tei-c.org/index.php/Remove-Namespaces.xsl
@@ -190,7 +194,7 @@ class Util:
                         result = dict(prepend.items() + {"$": parseChildren(x.getchildren())}.items())
 
                 if tag in final:
-                    if type(final[tag]) is not types.ListType:
+                    if not isinstance(final[tag], types.ListType):
                         final[tag] = [final[tag]]
 
                     final[tag].append(result)
@@ -288,7 +292,7 @@ class Util:
     # Handy for e.g. XPath expressions
     @staticmethod
     def stripNamespaces(node):
-        if not Util.xslt_strip_ns_doc:
+        if Util.xslt_strip_ns_doc is not None:
             Util.xslt_strip_ns_doc = etree.fromstring(Util.xslt_strip_ns)
 
         transform = etree.XSLT(Util.xslt_strip_ns_doc)
@@ -329,7 +333,7 @@ class Util:
                     elem = elem[x]
                 except ValueError:
                     elem = elem.get(x)
-        except:
+        except Exception:
             pass
 
         return elem
@@ -342,10 +346,10 @@ try:
     from cStringIO import StringIO
 
     log.info("Found cStringIO, good!")
-except:
+except Exception:
     from StringIO import StringIO
 
-    log.warning("Found StringIO (this is suboptimal, try cStringIO")
+    log.warning("Found %s - this is suboptimal, try cStringIO" % str(type(StringIO)))
 
 try:
     from lxml import etree
@@ -386,16 +390,19 @@ try:
     from osgeo import ogr
     from osgeo import osr
 except ImportError:
+    log.warn("No osgeo.gdal|ogr|osr packages found, trying direct import...")
     try:
         import gdal
         import ogr
         import osr
     except ImportError:
-        log.warn("No GDAL/OGR Python bindings. Ok if not using GDAL/OGR functions. See https://pypi.python.org/pypi/GDAL")
+        log.warn(
+            "No GDAL/OGR Python bindings. Ok if not using GDAL/OGR functions. See https://pypi.python.org/pypi/GDAL")
 
 if ogr and gdal and osr:
     log.info("Found GDAL/OGR Python bindings, super!!")
 
+
 class ConfigSection():
     def __init__(self, config_section):
         self.config_dict = dict(config_section)
@@ -404,7 +411,7 @@ class ConfigSection():
         return name in self.config_dict
 
     def get(self, name, default=None):
-        if not self.config_dict.has_key(name):
+        if name not in self.config_dict:
             return default
         return self.config_dict[name]
 
@@ -469,4 +476,3 @@ class ConfigSection():
 
     def to_string(self):
         return repr(self.config_dict)
-
